Crate eve_log_parser

source ·
This crate will give all the functionalities to read eve logs and parse them

Currently it will be able to read out damage and logi logs. It needs to be extended with other log types and the functionalities to read logs from the log directory as they’re being written by the game

Modules

Functions

  • Read any log line from eve and creates an appropriate log if possible